@@ -35,6 +35,7 @@ class ModelTaskType:
     qa: str = 'qa'
     qa_s: str = 'qa_s'
     seq_cls: str = 'seq_cls'
+    seq_cls_x: str = 'seq_cls_x'
     token_cls: str = 'token_cls'
     multi_choice: str = 'multi_choice'
     next_seq: str = 'next_seq'
@@ -53,16 +54,19 @@ class TaskModel:
         self.tokenizer = tokenizer
 
     def load(self, **kwargs):
+        cache_dir = kwargs['cache_dir']
         config = self.config.from_pretrained(
             self.model_path,
-            num_labels=kwargs['num_labels']
+            num_labels=kwargs['num_labels'],
+            cache_dir=cache_dir
         )
-        tokenizer = self.tokenizer.from_pretrained(self.model_path)
+        tokenizer = self.tokenizer.from_pretrained(self.model_path, cache_dir=cache_dir)
         unit_test = kwargs['unit_test']
         if not unit_test:
             model = self.model_class.from_pretrained(
                 self.model_path,
-                config=config
+                config=config,
+                cache_dir=cache_dir
             )
         else:
             model = None
